==> jc-1.4.0.tar.gz: soot/options/BCMOptions.h <==
// public class soot.options.BCMOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b2e1623f298adbc soot_options_BCMOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_BCMOptions_H_
#define _JC_soot_options_BCMOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_BCMOptions$sub_refs	_jc_soot_options_BCMOptions$sub_refs;
typedef struct _jc_soot_options_BCMOptions$sub_nonrefs	_jc_soot_options_BCMOptions$sub_nonrefs;
typedef struct _jc_soot_options_BCMOptions$refs	_jc_soot_options_BCMOptions$refs;
typedef struct _jc_soot_options_BCMOptions$nonrefs	_jc_soot_options_BCMOptions$nonrefs;
typedef struct _jc_soot_options_BCMOptions$object	_jc_soot_options_BCMOptions$object;

typedef const struct _jc_soot_options_BCMOptions$vmethods	_jc_soot_options_BCMOptions$vmethods;
typedef const struct _jc_soot_options_BCMOptions$vtable	_jc_soot_options_BCMOptions$vtable;
typedef const struct _jc_soot_options_BCMOptions$vtype	_jc_soot_options_BCMOptions$vtype;

// Constructors
extern void _jc_soot_options_BCMOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_BCMOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_BCMOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_BCMOptions$object *);
extern jboolean _jc_soot_options_BCMOptions$method$naive__5fside__5feffect$5a8a3f3892ad8319(_jc_env *, struct _jc_soot_options_BCMOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_BCMOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_BCMOptions$method_info$naive__5fside__5feffect$5a8a3f3892ad8319;

// Virtual methods structure
struct _jc_soot_options_BCMOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_BCMOptions$object *);
	jboolean	(*naive__5fside__5feffect$5a8a3f3892ad8319)(_jc_env *, struct _jc_soot_options_BCMOptions$object *);
};

// Vtable
struct _jc_soot_options_BCMOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_BCMOptions$vmethods	soot_options_BCMOptions;
};

// Vtype
struct _jc_soot_options_BCMOptions$vtype {
	_jc_type			type;
	_jc_soot_options_BCMOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_BCMOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_BCMOptions$refs {
    _jc_soot_options_BCMOptions$sub_refs	soot_options_BCMOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_BCMOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_BCMOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_BCMOptions$sub_nonrefs	soot_options_BCMOptions;
};

// Object instance structure
struct _jc_soot_options_BCMOptions$object {
	_jc_soot_options_BCMOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_BCMOptions$vtype	*vtype;
	_jc_soot_options_BCMOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_BCMOptions$vtype _jc_soot_options_BCMOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_BCMOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_BCMOptions$class_object;

#endif	/* _JC_soot_options_BCMOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/BCMOptions.h <==
// public class soot.options.BCMOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b2e1623f298adbc soot_options_BCMOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_BCMOptions_H_
#define _JC_soot_options_BCMOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_BCMOptions$sub_refs	_jc_soot_options_BCMOptions$sub_refs;
typedef struct _jc_soot_options_BCMOptions$sub_nonrefs	_jc_soot_options_BCMOptions$sub_nonrefs;
typedef struct _jc_soot_options_BCMOptions$refs	_jc_soot_options_BCMOptions$refs;
typedef struct _jc_soot_options_BCMOptions$nonrefs	_jc_soot_options_BCMOptions$nonrefs;
typedef struct _jc_soot_options_BCMOptions$object	_jc_soot_options_BCMOptions$object;

typedef const struct _jc_soot_options_BCMOptions$vmethods	_jc_soot_options_BCMOptions$vmethods;
typedef const struct _jc_soot_options_BCMOptions$vtable	_jc_soot_options_BCMOptions$vtable;
typedef const struct _jc_soot_options_BCMOptions$vtype	_jc_soot_options_BCMOptions$vtype;

// Constructors
extern void _jc_soot_options_BCMOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_BCMOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_BCMOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_BCMOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_BCMOptions$method$naive__5fside__5feffect$5a8a3f3892ad8319(_jc_env *, struct _jc_soot_options_BCMOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_BCMOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_BCMOptions$method_info$naive__5fside__5feffect$5a8a3f3892ad8319;

// Virtual methods structure
struct _jc_soot_options_BCMOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_BCMOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*naive__5fside__5feffect$5a8a3f3892ad8319)(_jc_env *, struct _jc_soot_options_BCMOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_BCMOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_BCMOptions$vmethods	soot_options_BCMOptions;
};

// Vtype
struct _jc_soot_options_BCMOptions$vtype {
	_jc_type			type;
	_jc_soot_options_BCMOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_BCMOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_BCMOptions$refs {
    _jc_soot_options_BCMOptions$sub_refs	soot_options_BCMOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_BCMOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_BCMOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_BCMOptions$sub_nonrefs	soot_options_BCMOptions;
};

// Object instance structure
struct _jc_soot_options_BCMOptions$object {
	_jc_soot_options_BCMOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_BCMOptions$vtype	*vtype;
	_jc_soot_options_BCMOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_BCMOptions$vtype _jc_soot_options_BCMOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_BCMOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_BCMOptions$class_object;

#endif	/* _JC_soot_options_BCMOptions_H_ */
